==> ucsmsdk-0.9.1.0.tar.gz: ucsmsdk-0.9.1.0/ucsmsdk/mometa/sysdebug/SysdebugTechSupportFsmStage.py <==
"""This module contains the general information for SysdebugTechSupportFsmStage ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class SysdebugTechSupportFsmStageConsts:
    LAST_UPDATE_TIME_ = ""
    NAME_DELETE_TECH_SUP_FILE_BEGIN = "DeleteTechSupFileBegin"
    NAME_DELETE_TECH_SUP_FILE_FAIL = "DeleteTechSupFileFail"
    NAME_DELETE_TECH_SUP_FILE_LOCAL = "DeleteTechSupFileLocal"
    NAME_DELETE_TECH_SUP_FILE_PEER = "DeleteTechSupFilePeer"
    NAME_DELETE_TECH_SUP_FILE_SUCCESS = "DeleteTechSupFileSuccess"
    NAME_DOWNLOAD_BEGIN = "DownloadBegin"
    NAME_DOWNLOAD_COPY_PRIMARY = "DownloadCopyPrimary"
    NAME_DOWNLOAD_COPY_SUB = "DownloadCopySub"
    NAME_DOWNLOAD_DELETE_PRIMARY = "DownloadDeletePrimary"
    NAME_DOWNLOAD_DELETE_SUB = "DownloadDeleteSub"
    NAME_DOWNLOAD_FAIL = "DownloadFail"
    NAME_DOWNLOAD_SUCCESS = "DownloadSuccess"
    NAME_INITIATE_BEGIN = "InitiateBegin"
    NAME_INITIATE_FAIL = "InitiateFail"
    NAME_INITIATE_LOCAL = "InitiateLocal"
    NAME_INITIATE_SUCCESS = "InitiateSuccess"
    NAME_NOP = "nop"
    STAGE_STATUS_FAIL = "fail"
    STAGE_STATUS_IN_PROGRESS = "inProgress"
    STAGE_STATUS_NOP = "nop"
    STAGE_STATUS_PENDING = "pending"
    STAGE_STATUS_SKIP = "skip"
    STAGE_STATUS_SUCCESS = "success"
    STAGE_STATUS_THROTTLED = "throttled"


class SysdebugTechSupportFsmStage(ManagedObject):
    """This is SysdebugTechSupportFsmStage class."""

    consts = SysdebugTechSupportFsmStageConsts()
    naming_props = set([u'name'])

    mo_meta = MoMeta("SysdebugTechSupportFsmStage", "sysdebugTechSupportFsmStage", "stage-[name]", VersionMeta.Version211a, "OutputOnly", 0xf, [], [""], [u'sysdebugTechSupportFsm'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "last_update_time": MoPropertyMeta("last_update_time", "lastUpdateTime", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [""], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version211a, MoPropertyMeta.NAMING, None, None, None, None, ["DeleteTechSupFileBegin", "DeleteTechSupFileFail", "DeleteTechSupFileLocal", "DeleteTechSupFilePeer", "DeleteTechSupFileSuccess", "DownloadBegin", "DownloadCopyPrimary", "DownloadCopySub", "DownloadDeletePrimary", "DownloadDeleteSub", "DownloadFail", "DownloadSuccess", "InitiateBegin", "InitiateFail", "InitiateLocal", "InitiateSuccess", "nop"], []), 
        "order": MoPropertyMeta("order", "order", "ushort", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "retry": MoPropertyMeta("retry", "retry", "byte", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []), 
        "stage_status": MoPropertyMeta("stage_status", "stageStatus", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["fail", "inProgress", "nop", "pending", "skip", "success", "throttled"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "lastUpdateTime": "last_update_time", 
        "name": "name", 
        "order": "order", 
        "retry": "retry", 
        "rn": "rn", 
        "sacl": "sacl", 
        "stageStatus": "stage_status", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.last_update_time = None
        self.order = None
        self.retry = None
        self.sacl = None
        self.stage_status = None
        self.status = None

        ManagedObject.__init__(self, "SysdebugTechSupportFsmStage", parent_mo_or_dn, **kwargs)

==> ucsmsdk-0.9.9.tar.gz: ucsmsdk-0.9.9/ucsmsdk/mometa/sysdebug/SysdebugTechSupportFsmStage.py <==
"""This module contains the general information for SysdebugTechSupportFsmStage ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class SysdebugTechSupportFsmStageConsts:
    LAST_UPDATE_TIME_ = ""
    NAME_DELETE_TECH_SUP_FILE_BEGIN = "DeleteTechSupFileBegin"
    NAME_DELETE_TECH_SUP_FILE_FAIL = "DeleteTechSupFileFail"
    NAME_DELETE_TECH_SUP_FILE_LOCAL = "DeleteTechSupFileLocal"
    NAME_DELETE_TECH_SUP_FILE_PEER = "DeleteTechSupFilePeer"
    NAME_DELETE_TECH_SUP_FILE_SUCCESS = "DeleteTechSupFileSuccess"
    NAME_DOWNLOAD_BEGIN = "DownloadBegin"
    NAME_DOWNLOAD_COPY_PRIMARY = "DownloadCopyPrimary"
    NAME_DOWNLOAD_COPY_SUB = "DownloadCopySub"
    NAME_DOWNLOAD_DELETE_PRIMARY = "DownloadDeletePrimary"
    NAME_DOWNLOAD_DELETE_SUB = "DownloadDeleteSub"
    NAME_DOWNLOAD_FAIL = "DownloadFail"
    NAME_DOWNLOAD_SUCCESS = "DownloadSuccess"
    NAME_INITIATE_BEGIN = "InitiateBegin"
    NAME_INITIATE_FAIL = "InitiateFail"
    NAME_INITIATE_LOCAL = "InitiateLocal"
    NAME_INITIATE_SUCCESS = "InitiateSuccess"
    NAME_NOP = "nop"
    STAGE_STATUS_FAIL = "fail"
    STAGE_STATUS_IN_PROGRESS = "inProgress"
    STAGE_STATUS_NOP = "nop"
    STAGE_STATUS_PENDING = "pending"
    STAGE_STATUS_SKIP = "skip"
    STAGE_STATUS_SUCCESS = "success"
    STAGE_STATUS_THROTTLED = "throttled"


class SysdebugTechSupportFsmStage(ManagedObject):
    """This is SysdebugTechSupportFsmStage class."""

    consts = SysdebugTechSupportFsmStageConsts()
    naming_props = set([u'name'])

    mo_meta = MoMeta("SysdebugTechSupportFsmStage", "sysdebugTechSupportFsmStage", "stage-[name]", VersionMeta.Version211a, "OutputOnly", 0xf, [], [""], [u'sysdebugTechSupportFsm'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "last_update_time": MoPropertyMeta("last_update_time", "lastUpdateTime", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [""], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version211a, MoPropertyMeta.NAMING, None, None, None, None, ["DeleteTechSupFileBegin", "DeleteTechSupFileFail", "DeleteTechSupFileLocal", "DeleteTechSupFilePeer", "DeleteTechSupFileSuccess", "DownloadBegin", "DownloadCopyPrimary", "DownloadCopySub", "DownloadDeletePrimary", "DownloadDeleteSub", "DownloadFail", "DownloadSuccess", "InitiateBegin", "InitiateFail", "InitiateLocal", "InitiateSuccess", "nop"], []),
        "order": MoPropertyMeta("order", "order", "ushort", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "retry": MoPropertyMeta("retry", "retry", "byte", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "stage_status": MoPropertyMeta("stage_status", "stageStatus", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["fail", "inProgress", "nop", "pending", "skip", "success", "throttled"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "lastUpdateTime": "last_update_time", 
        "name": "name", 
        "order": "order", 
        "retry": "retry", 
        "rn": "rn", 
        "sacl": "sacl", 
        "stageStatus": "stage_status", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.last_update_time = None
        self.order = None
        self.retry = None
        self.sacl = None
        self.stage_status = None
        self.status = None

        ManagedObject.__init__(self, "SysdebugTechSupportFsmStage", parent_mo_or_dn, **kwargs)
